﻿local mod = MorgDKP2:NewModule("TakeBid", "AceComm-3.0", "AceSerializer-3.0")
local L = LibStub("AceLocale-3.0"):GetLocale("MorgDKP2")

local mdkp = MorgDKP2

mod.modName = L["TakeBid DKP"]
mod.modref = "TakeBid"

local Player = UnitName("player")
local db
local fmt = string.format
local floor = math.floor

local defaults = { 
	profile = {
		takebidstep = 1,
		takeoverbid = 50,
		takeminbid = 10
	},
}

function mod:GetOptions()
	return options
end

function mod:GetName()
	return mod.modName, mod.modref
end

function mod:IsDKP()
	return true
end

function mod:OnInitialize()
	self.db = mdkp.db:RegisterNamespace("TakeBid", defaults)
	
end

function mod:OnEnable()
	db = mdkp.db.profile
	db.moduleON["TakeBid"] = true
	
	self.master = {}
end

function mod:OnDisable()
	db.moduleON["TakeBid"] = nil
				
end

function mod:UpdateDB()
	db = mdkp.db.profile
end

function mod:Toggle(info, v)
	mdkp.db.profile.modules.TakeBid = v
	if v then mod:Enable()
	else mod:Disable() end
	self:DKPChange(mod.modName)
end

function mod:SetOpt(info, v)
	local db = mod.db.profile
	local opt = info[#info]
	db[opt] = v
end

function mod:GetOpt(info)
	local db = mod.db.profile
	local opt = info[#info]
	return db[opt]
end

function mod:StartAuction(id, itempoints, queries, link, mbidtable)
	self:AtStartQuery(id, queries)
	self:SendCommMessage("MorgBid2", self:Serialize("TAKEBID", id, itempoints, queries, db.quality, self.db.profile.takebidstep, self.db.profile.takeoverbid, isrand, link, db.mbidupdating, mbidtable, self.db.profile.takeminbid, db.attendneed), "RAID")
end

function mod:AtStartQuery(id, queries)
	self.master[id] = true
	if self:PlayerIncluded(queries) then self.master[id] = nil end
end

function mod:PlayerIncluded(dkp)
	for i, v in pairs(dkp) do
		if v[1].n == Player then
			return true
		end
	end
	return false
end

function mod:AddBids(itemid)
	self.master[itemid] = true 
	if mdkp.querytooltips[itemid] then
		for  i,v in pairs(mdkp.querytooltips[itemid]) do
			if v[5] then
				v[3].n = v[5]
			end
		end
	end
end

function mod:OnBidWhisper(sender, item, reply, bid)
	for i,v in ipairs(mdkp.querytooltips[item]) do
		if v[1].n == sender then
			v[2] = reply
			if reply == "TAKE" then 
				if self.master[item] then v[3].n = bid
				else 
					v[3].n = 0
					v[5] = bid
				end
			end
			break
		end
	end		
end

function mod:GetPlayerPoints(name, POOL, showearned)
	if not showearned or showearned == 1 then return db.info[name][POOL].points end
	if showearned == 2 then return db.info[name][POOL].earned
	elseif showearned == 3 then return db.info[name][POOL].attend
	end
end

function mod:GetItemValue(itemid, player, POOL)
	local itempoints = db.items[itemid].points
	if mdkp.querytooltips[itemid] then
		for  i,v in pairs(mdkp.querytooltips[itemid]) do
			if v[1].n == player then
				if v[2] == "TAKE" then 
					itempoints = v[3].n
				end
			end
		end
	end
	return itempoints
end

function mod:ItemRecorded(id, looter, POOL, points, itempoints, link)
	if looter == L["Bank"] then return end
	points = points - itempoints
	self:AwardItem(id, looter, POOL, points, itempoints, link)
end

function mod:ItemRebate(id, looter, POOL, itempoints, link)
	if not id or looter == L["Bank"] then return end
	self:AdjustDKPPoints(looter, looter, POOL, nil, itempoints)
end
